0.2.6 (2023-02-20)
------------------

Compatibility with django-crispy-forms >= 2

* Added badge for supported Python versions
* Added some pagination documentation
* Added bootstrap4 template pack + settings
* Fixed date facets breaking out of their container
